format everything properly get a good formatting guideline, black I think is good

podemos usar isto para ver quando as coisas sao compiladas e recompiladas


jax.config.update("jax_log_compiles", True)



